from setuptools import setup

setup(
    name = "pygame_shaders",
    version = "0.0.2",
    description = "a library to easily intergrate shaders into your new or existing pygame projects",
    py_modules = ["pygame_shaders"],
    package_dir = {"": "src"}
)